@@ -86,6 +86,7 @@ def print_same(path):  # print file list
     a = traverse_files(path)
     return find_same(f2md5(a), a)
 
+
 def find_empty_dir(path):  # Traverse files
     Dirlists = []
     try:
@@ -105,5 +106,23 @@ def find_empty_dir(path):  # Traverse files
                     Dirlists = Dirlists + traverse_files(path + '/' + file)
     return Dirlists
 
+
+def find_big_file(path, size):  # Traverse files
+    Flists = []
+    try:
+        os.listdir(path)
+    except:
+        return Flists
+    for file in os.listdir(path):
+        if os.access(path + '/' + file, os.R_OK):
+            if os.path.isfile(path + '/' + file):
+                if os.access(path + '/' + file, os.R_OK) and not 'desktop.ini' in file:
+                    if os.path.getsize(path + '/' + file) >= size:
+                        Flists.append({'parh':path + '/' + file, 'size': os.path.getsize(path + '/' + file)})
+            else:
+                Flists = Flists + find_big_file(path + '/' + file, size)
+    return Flists
+
+
 if __name__ == '__main__':
     print_same('.')
